You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2013/10/13 11:15:09 UTC

[13/13] git commit: CAMEL-6859: AvailablePortFinder should allow max at IPv4 range.

CAMEL-6859: AvailablePortFinder should allow max at IPv4 range.


Project: http://git-wip-us.apache.org/repos/asf/camel/repo
Commit: http://git-wip-us.apache.org/repos/asf/camel/commit/1765f1a2
Tree: http://git-wip-us.apache.org/repos/asf/camel/tree/1765f1a2
Diff: http://git-wip-us.apache.org/repos/asf/camel/diff/1765f1a2

Branch: refs/heads/camel-2.11.x
Commit: 1765f1a2e9b7ef17b3ba51a55dff62c178d207da
Parents: 6e33f34
Author: Claus Ibsen <da...@apache.org>
Authored: Sun Oct 13 11:13:01 2013 +0200
Committer: Claus Ibsen <da...@apache.org>
Committed: Sun Oct 13 11:14:40 2013 +0200

----------------------------------------------------------------------
 .../org/apache/camel/test/AvailablePortFinder.java     | 10 ++++------
 .../org/apache/camel/testng/AvailablePortFinder.java   | 13 ++++++-------
 2 files changed, 10 insertions(+), 13 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/camel/blob/1765f1a2/components/camel-test/src/main/java/org/apache/camel/test/AvailablePortFinder.java
----------------------------------------------------------------------
diff --git a/components/camel-test/src/main/java/org/apache/camel/test/AvailablePortFinder.java b/components/camel-test/src/main/java/org/apache/camel/test/AvailablePortFinder.java
index 3253edd..57a1218 100644
--- a/components/camel-test/src/main/java/org/apache/camel/test/AvailablePortFinder.java
+++ b/components/camel-test/src/main/java/org/apache/camel/test/AvailablePortFinder.java
@@ -27,21 +27,19 @@ import org.slf4j.LoggerFactory;
 
 /**
  * Finds currently available server ports.
- *
- * @see <a href="http://www.iana.org/assignments/currentMinPort-numbers">IANA.org</a>
  */
 public final class AvailablePortFinder {
 
     /**
-     * The minimum server currentMinPort number. Set at 1100 to avoid returning privileged
-     * currentMinPort numbers.
+     * The minimum server currentMinPort number for IPv4.
+     * Set at 1100 to avoid returning privileged currentMinPort numbers.
      */
     public static final int MIN_PORT_NUMBER = 1100;
 
     /**
-     * The maximum server currentMinPort number.
+     * The maximum server currentMinPort number for IPv4.
      */
-    public static final int MAX_PORT_NUMBER = 49151;
+    public static final int MAX_PORT_NUMBER = 65535;
 
     private static final Logger LOG = LoggerFactory.getLogger(AvailablePortFinder.class);
 

http://git-wip-us.apache.org/repos/asf/camel/blob/1765f1a2/components/camel-testng/src/main/java/org/apache/camel/testng/AvailablePortFinder.java
----------------------------------------------------------------------
diff --git a/components/camel-testng/src/main/java/org/apache/camel/testng/AvailablePortFinder.java b/components/camel-testng/src/main/java/org/apache/camel/testng/AvailablePortFinder.java
index 5479c42..0f586e6 100644
--- a/components/camel-testng/src/main/java/org/apache/camel/testng/AvailablePortFinder.java
+++ b/components/camel-testng/src/main/java/org/apache/camel/testng/AvailablePortFinder.java
@@ -23,20 +23,19 @@ import java.util.NoSuchElementException;
 
 /**
  * Finds currently available server ports.
- *
- * @see <a href="http://www.iana.org/assignments/port-numbers">IANA.org</a>
  */
 public final class AvailablePortFinder {
+
     /**
      * The minimum server port number. Set at 1024 to avoid returning privileged
      * port numbers.
      */
-    public static final int MIN_PORT_NUMBER = 1024;
+    public static final int MIN_PORT_NUMBER = 1100;
 
     /**
-     * The maximum server port number.
+     * The maximum server currentMinPort number for IPv4.
      */
-    public static final int MAX_PORT_NUMBER = 49151;
+    public static final int MAX_PORT_NUMBER = 65535;
 
     /**
      * Creates a new instance.
@@ -23,20 +23,19 @@ import java.util.NoSuchElementException;
     /**
-     * The minimum server port number. Set at 1024 to avoid returning privileged
-     * port numbers.
+     * The minimum server currentMinPort number for IPv4.
+     * Set at 1100 to avoid returning privileged currentMinPort numbers.
      */